package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@("`0`````````````"`!8````!`````(``)Q``````````0```````
M`,-P``````!``#@`"0!``!L`&@````8````%`````````$``````@```0```
M``"```!``````````?@````````!^``````````(`````P````0````````"
M.`````"```(X`````(```C@`````````#P`````````/``````````$````!
M````!0```````````````(``````````@````````````+(T````````LC0`
M```````0``````$````&````````O<@`````@`#-R`````"``,W(````````
M!'`````````4T````````!```````@````8```````"]X`````"``,W@````
M`(``S>`````````"(`````````(@``````````@````$````!`````````)(
M`````(```D@`````@``"2`````````!$`````````$0`````````!&1TY5``
M```$````````J[P`````@`"KO`````"``*N\`````````.0`````````Y```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+W(`````(``S<@`````
M@`#-R`````````(X`````````C@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````$`````%'3E4```````````(````&````(`````0````4`````T=.
M50`4P2?JAAS^CWD#H34,(FL\K:?-_@````````!#````!@```!`````*`!`&
M`B@`$*`8$`)6`$```!$1`$@@!`B"```@``(0"``@`D@``````*`"A```"P`.
M2<0(:``$"$$**$$&E11".)8$8`2!B%@H&```4`I""0@````(0D`!`1"0$`@`
M!,",@8`0@0@``0(`0"R`F8)`0`D`(```!`$"8%27BH0CD00`````````!@``
M``@````*````"P````P````1````$@```!,````5````&````!P````>````
M```````````?````(0```"(````C`````````"8````I````*@```"P````M
M````+@```"\````Q````,P```#4````X```````````````Y`````````#H`
M```[````/````#X```!``````````$,```!$````10```$<```!)````2P``
M`$T```!.````4````%$```!2````4P```%0```!5````5P```%@```!;````
M7````%X```!?``````````````!A````8@```&0`````5Q"*"AGV`J-QLM7(
M2?O@H\6%<VTBX=`K_ZY*SI_*J]Z0[UJB&,17XJC'(I]@;*'['(OR.<CO\D*O
M##_-']_%;ND0D'S-LFP%#3FM/,#C2ZS"P_OH`I`_[?^'I`9PXV]WI/DC`?8]
M3B[Q6NH7D`6)Q6M*\'L02V9"#8)T@&($K9.;G*E^#N_3ZE<UV8O!\.,W?);P
MABU'WL^>XA0-O=:?&\+=F(N6FZ16#O&-N>W;8C("L'0AB_8L[&^+`;,!QD?B
MYYU(L)[CS=M`G+G%+#_EPWR=34&%I3(%XQ'N4!R3WNVVF\4N:-0BF=-P!XC%
MCD%\:Z/=IW.Q#BT+ESH-/>`.QH&<^8<2[YA@7@#WVWR6?CY(_M\M@OK08M9#
M"6M26I)7^5$+[@\[FEM\FG]K[-5%0P[D_R$?0#M93R"%WX0$4=)\U&35'T`Y
MR2#.(_8*`J?@?)+CN_PLG]$<D]M6?4O0O5]]&U'_AX["').5NQW3V_-FS*]F
M#^_2_?]](DH<6''9`````````````````````````````````````````!$@
M`````````````````````````````G,2````````````````````````````
M`"T@`````````````````````````````#P@````````````````````````
M`````%`@`````````````````````````````0(1```8`````(``TE``````
M`````0```6\2`````````(``'Y```````````````4X2`````````(``(5``
M````````````!'H2```-`````(``5(@````````!Q@```P@2`````````(``
M([```````````````U<2`````````(``(Q```````````````_,2````````
M`(``'+```````````````8@2`````````(``'M```````````````D<2````
M`````(``'O```````````````T,2`````````(``'[```````````````V$2
M`````````(``(+``````````````!)P2```-`````(``5T`````````!5```
M`R41```8`````(``TD``````````"````.$2`````````(``'G``````````
M`````HH2`````````(``(S```````````````_P2```-`````(``:*@`````
M````O````'@2`````````(``(!```````````````I(2`````````(``(3``
M`````````````>02`````````(``'W``````````````!#L1```/`````(``
M:H``````````!````+X2`````````(``(-```````````````982````````
M`(``(/```````````````RP2`````````(``'?```````````````Q,2````
M`````(``)!```````````````C82`````````(``()```````````````WX2
M`````````(``(#```````````````W<2`````````(``(E``````````````
M`Y$A```8`````(``TC@`````````"````;T2`````````(``'5``````````
M`````N82`````````(``'7```````````````LH2`````````(``(7``````
M`````````D\2`````````(``(Y```````````````^$2```-`````(``5P``
M````````.@```\H2```.`````(``:E```````````````(<2`````````(``
M(U```````````````:\2`````````(``(I```````````````3T2````````
M`(``'/``````````````!"$2```-`````(``6)@````````+@````\`2```-
M`````(``:D@``````````@```V\2`````````(``'-```````````````-,2
M`````````(``'1```````````````2T1```8`````(``TD@`````````!```
M!(D2```+`````(``'!``````````````!#02```-`````(``)Q``````````
M`````QL2`````````(``(W```````````````=@2`````````(``'Q``````
M````````!*X2```-`````(``5E``````````K```!`@2```-`````(``4K``
M````````4@```0\2`````````(``('``````````````!&`2```-`````(``
M:>``````````9````Y`1```8`````(``TC@`````````"```!(<2```-````
M`(``3J``````````.@```C$2`````````(``')```````````````:$2````
M`````(``'C```````````````NP2`````````(``(A```````````````M@2
M`````````(``(G```````````````]`2```-`````(``4'@`````````!@``
M`3@2`````````(``';``````````````!'`1```7`````(``TC``````````
M"```!+P2```-`````(``:6@`````````2````Y(A```8`````(``TC@`````
M````"````&H2`````````(``(9``````````````!#`@```7`````(``TA@`
M`````````````L(2`````````(``'A```````````````)X2`````````(``
M(K```````````````BH2`````````(``(%```````````````IL2````````
M`(``(]```````````````H42`````````(``']```````````````7\2````
M`````(``(O```````````````>L2`````````(``'I``````````````!"X0
M```7`````(``TA@``````````````4(2`````````(``(;``````````````
M`S,2`````````(``'K```````````````F,2`````````(``(_``````````
M`````XL2```-`````(``)#`````````"W````Z@0```7`````(``TC@`````
M````````!(\2```-`````(``4(`````````"*@```1P2`````````(``(C``
M`````````````/,2`````````(``(M```````````````<T2`````````(``
M(?``````````````!-@2```-`````(``9!@````````$C@```J02````````
M`(``'=```````````````K42`````````(``'U``````````````!$H2```-
M`````(``3T@````````!+@```[L0```8`````(``XI@``````````````SP2
M`````````(``'3```````````````M\2`````````(``''``````````````
M`*\2`````````(``'9```````````````6$2`````````(``'E``````````
M`````M$2`````````(``'S```````````````U`2`````````(``'_``````
M`````````?81```8`````(``TE(`````````$P``!!42```-`````(``4P@`
M```````!?````KP2`````````(``(1```````````````OH2`````````(``
M(=```````````````Z\0```8`````(``TC@```````````!L:6)P97)L+G-O
M+C4N,C``7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R
M=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F54
M86)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%V95]D
M97-T<G5C=&]R7W@`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V
M7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=U-6
M<'8`4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3
M`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O
M+C``;W!E;C8T`')E860`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F
M;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M=&]K`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`%]?<W1R;F-P>5]C:&L`
M7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E
M861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?
M7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`%]?;&EB8U]S=&%R=%]M86EN
M`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?
M96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R
M;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P
M87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]0
M05)?0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR
M`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-`````````4`````
M`````````````0`"``(``@````,`!@`$``$``@````(``0````(``@`!````
M```"``(``P`"``(``@````(``@`#``$``0```````@`!``$``@```````0`!
M``(````!``$````!``(``0`#````!``"``$````!``$``@````$``@````,`
M`@`"```````!`````@`#``$``0`!``````````$`!``"``$``0`"``(`````
M``(``@````$``@`&``$````!``$```(:````$````"`-:6D2`````P``!.X`
M``````$`!````FD````0``````EI&70````&```$^````!`):1ER````!0``
M!00````0#6EI%`````0```40````$`UI:1(````"```$[@``````````@`#2
M"`````(````*````````````````@`#2$`````,````*````````````````
M@`#2.````#@````)````````````````@`#20````!(````)````````````
M````@`#22````"\````)````````````````@`#24`````8````)````````
M````````@`#24@```&$````)````````````````@`#0&````%P````+````
M````````````@`#0(````#H````+````````````````@`#0*`````P````+
M````````````````@`#0,````"T````+````````````````@`#0.````"H`
M```+````````````````@`#00````"X````+````````````````@`#02```
M`%L````+````````````````@`#04````"(````+````````````````@`#0
M6````",````+````````````````@`#08````%T````+````````````````
M@`#0:````#\````+````````````````@`#0<````%<````+````````````
M````@`#0>````!P````+````````````````@`#0@````$4````+````````
M````````@`#0B````#L````+````````````````@`#0D````%X````+````
M````````````@`#0F````!,````+````````````````@`#0H````$L````+
M````````````````@`#0J````$X````+````````````````@`#0L`````T`
M```+````````````````@`#0N`````X````+````````````````@`#0P```
M`#,````+````````````````@`#0R````%\````+````````````````@`#0
MT````%@````+````````````````@`#0V````!@````+````````````````
M@`#0X`````<````+````````````````@`#0Z`````\````+````````````
M````@`#0\````$D````+````````````````@`#0^````&`````+````````
M````````@`#1`````!8````+````````````````@`#1"````!\````+````
M````````````@`#1$````$<````+````````````````@`#1&````#8````+
M````````````````@`#1(````!X````+````````````````@`#1*````!``
M```+````````````````@`#1,````!H````+````````````````@`#1.```
M`!L````+````````````````@`#10````&,````+````````````````@`#1
M2````!<````+````````````````@`#14`````@````+````````````````
M@`#16````"0````+````````````````@`#18````$,````+````````````
M````@`#1:````$T````+````````````````@`#1<````&0````+````````
M````````@`#1>````%4````+````````````````@`#1@````#P````+````
M````````````@`#1B````%,````+````````````````@`#1D````"`````+
M````````````````@`#1F````#T````+````````````````@`#1H````"D`
M```+````````````````@`#1J````$8````+````````````````@`#1L```
M`%0````+````````````````@`#1N````$H````+````````````````@`#1
MP`````L````+````````````````@`#1R````!0````+````````````````
M@`#1T````"@````+````````````````@`#1V````#(````+````````````
M````@`#1X````"4````+````````````````@`#1Z`````H````+````````
M````````@`#1\````$@````+````````````````@`#1^````$\````+````
M````````````@`#2`````!T````+``````````#K;_`P`"2Y!``?I_O_8.,0
M\```),#```!9[L`0``!:\^,0$```!+D"`!&GA``##>'C0/$0``3K;_#0``0'
M]`<'XQ#P.``DP!```%G5T@?P,!`(XQ`0$``$!_$'``<`!P#`$```6=3C$!``
M``0'\0T0XQ`0#``4P/3____E`````,`0``!9R.,0$```!`?Q#1#C$!`,`!3`
M]/___]4````8P!```%F\XQ`0```$!_$-$.,0$`P`%,#T____Q0```##`$```
M6;#C$!````0'\0T0XQ`0#``4P/3___^U````2,`0``!9I.,0$```!`?Q#1#C
M$!`,`!3`]/___Z4```!@P!```%F8XQ`0```$!_$-$.,0$`P`%,#T____E0``
M`'C`$```68SC$!````0'\0T0XQ`0#``4P/3___^%````D,`0``!9@.,0$```
M!`?Q#1#C$!`,`!3`]/___W4```"HP!```%ETXQ`0```$!_$-$.,0$`P`%,#T
M____90```,#`$```66CC$!````0'\0T0XQ`0#``4P/3___]5````V,`0``!9
M7.,0$```!`?Q#1#C$!`,`!3`]/___T4```#PP!```%E0XQ`0```$!_$-$.,0
M$`P`%,#T____-0```0C`$```643C$!````0'\0T0XQ`0#``4P/3___\E```!
M(,`0``!9..,0$```!`?Q#1#C$!`,`!3`]/___Q4```$XP!```%DLXQ`0```$
M!_$-$.,0$`P`%,#T____!0```5#`$```62#C$!````0'\0T0XQ`0#``4P/3_
M__[U```!:,`0``!9%.,0$```!`?Q#1#C$!`,`!3`]/___N4```&`P!```%D(
MXQ`0```$!_$-$.,0$`P`%,#T___^U0```9C`$```6/SC$!````0'\0T0XQ`0
M#``4P/3___[%```!L,`0``!8\.,0$```!`?Q#1#C$!`,`!3`]/___K4```'(
MP!```%CDXQ`0```$!_$-$.,0$`P`%,#T___^I0```>#`$```6-CC$!````0'
M\0T0XQ`0#``4P/3___Z5```!^,`0``!8S.,0$```!`?Q#1#C$!`,`!3`]/__
M_H4```(0P!```%C`XQ`0```$!_$-$.,0$`P`%,#T___^=0```BC`$```6+3C
M$!````0'\0T0XQ`0#``4P/3___YE```"0,`0``!8J.,0$```!`?Q#1#C$!`,
M`!3`]/___E4```)8P!```%B<XQ`0```$!_$-$.,0$`P`%,#T___^10```G#`
M$```6)#C$!````0'\0T0XQ`0#``4P/3___XU```"B,`0``!8A.,0$```!`?Q
M#1#C$!`,`!3`]/___B4```*@P!```%AXXQ`0```$!_$-$.,0$`P`%,#T___^
M%0```KC`$```6&SC$!````0'\0T0XQ`0#``4P/3___X%```"T,`0``!88.,0
M$```!`?Q#1#C$!`,`!3`]/___?4```+HP!```%A4XQ`0```$!_$-$.,0$`P`
M%,#T___]Y0```P#`$```6$CC$!````0'\0T0XQ`0#``4P/3___W5```#&,`0
M``!8/.,0$```!`?Q#1#C$!`,`!3`]/___<4```,PP!```%@PXQ`0```$!_$-
M$.,0$`P`%,#T___]M0```TC`$```6"3C$!````0'\0T0XQ`0#``4P/3___VE
M```#8,`0``!8&.,0$```!`?Q#1#C$!`,`!3`]/___94```-XP!```%@,XQ`0
M```$!_$-$.,0$`P`%,#T___]A0```Y#`$```6`#C$!````0'\0T0XQ`0#``4
MP/3___UU```#J,`0``!7].,0$```!`?Q#1#C$!`,`!3`]/___64```/`P!``
M`%?HXQ`0```$!_$-$.,0$`P`%,#T___]50```]C`$```5]SC$!````0'\0T0
MXQ`0#``4P/3___U%```#\,`0``!7T.,0$```!`?Q#1#C$!`,`!3`]/___34`
M``0(P!```%?$XQ`0```$!_$-$.,0$`P`%,#T___])0``!"#`$```5[CC$!``
M``0'\0T0XQ`0#``4P/3___T5```$.,`0``!7K.,0$```!`?Q#1#C$!`,`!3`
M]/___04```10P!```%>@XQ`0```$!_$-$.,0$`P`%,#T___\]0``!&C`$```
M5Y3C$!````0'\0T0XQ`0#``4P/3___SE```$@,`0``!7B.,0$```!`?Q#1#C
M$!`,`!3`]/___-4```28P!```%=\XQ`0```$!_$-$.,0$`P`%,#T___\Q0``
M!+#`$```5W#C$!````0'\0T0XQ`0#``4P/3___RU```$R,`0``!79.,0$```
M!`?Q#1#C$!`,`!3`]/___*4```3@P!```%=8XQ`0```$!_$-$.,0$`P`%,#T
M___\E0``!/C`$```5TSC$!````0'\0T0XQ`0#``4P/3___R%```%$,`0``!7
M0.,0$```!`?Q#1#C$!`,`!3`]/___'4```4HP!```%<TXQ`0```$!_$-$.,0
M$`P`%,#T___\90``!4#`$```5RCC$!````0'\0T0XQ`0#``4P/3___Q5```%
M6,`0``!7'.,0$```!`?Q#1#C$!`,`!3`]/___$4```5PP!```%<0XQ`0```$
M!_$-$.,0$`P`%,#T___\-0``!8C`$```5P3C$!````0'\0T0XQ`0#``4P/3_
M__PE```%H,`0``!6^.,0$```!`?Q#1#C$!`,`!3`]/___!4```6XZV_P,``D
MP-```"01I_O_.+)/`!#K$0`@``VR3P`1XS#PJ``DXT#PH``D4"#PM$$P\*A!
M(/"T04#PH-('\,`0*,#E___]T,`P___^;<`@____&KD$`$/`Y0``(I7`$```
M5N*5`!``IX0`VL#```!6U^,@P```%L#E____=98")++C(,```!;`Y?___VU8
M$/"TIQH`!98!)+*Y%``AN0(`(K.F``*G1`#CLT4`0"@$[0#0&``:[0#0$``9
MIR0`[^LB``,`#<#E___]#N,P\*@`!,!0``!>P,`0``!6E>,`,```!.,`(```
M)*<(``3`P```7JY0`%``P%```"5$6$#PM.-0(`@`).,0$```!,!0```E.^,@
MP```).-0(!@`).,0(!``)*=.``&GQ``>&`1!,#`(I\@`!:=9\`"G"O__N10`
M'.L1``,`#>.P,```!*?*``&G.P`(01$@`..Q7_@`)*<&_^\8%*<:``2Y%``1
MZQ$``P`-I\GP`,`P``!>=*=*``.G"0``01$@`+D$`%+C`<_X`"3C(#````2Y
M!`"CN10`1,`P```4AZ=I``#`Y?___@H2(AC"IX0`4>,@H```!,#E___\($$P
M\+S`(```(YS`Y0``#Z"Y`@`BIX0`4.,@H```!,#E___[SL#E___]N[)/`!#K
M$0`@``VR3P`1N10`+-4'\,`0**=T`&+C0/$X``3K;_#X``0'],#E___\(\`P
M``!>(+D"`"+C(#```"2GA`!1P.7___N6P!```%7ON00`P>,@$```%L#E___^
MBY(`*)6G]/\.XR"@```$P.7___XQ&,*G]/^J:$#0`&A@T`BS2@`$I_3_&<"P
M``!=[^,@L```!+D"`"*GA``0P.4``"#UI_3_I<`@```CV,`P``!5PL#E___\
M_D$P\+S`(```(P+`Y0``#R[C(+```"2Y`@`BIX3_C:?T_^/`Y?__^VJG*0`!
MP.7___QE!P<'!T%`\`CC,/````2G"?_PN8``\*?[_U#7!_``\`#K[_"@`"1!
M</"@P&```"&)P%```"%2P"#___YWP.7___QT``#`4```(9S`$```57%!$!`'
MXQ!0"``)XQ!0```A!\[`$+__[$FY`@`1!X[`(```55\'\0<'!P<'!\!0```A
MB,`P``!55>,P4```">L3``,`"NLQ`#\`#+D(`#'K,P`!``H'CL`0O__L)[D"
M`!$'CL`@``!5/0?Q!P?KW_!H`"3`T```54VG^_]@E0#0`*=T``?`Y?___[B2
M`=``XT#Q$``$Z]_Q"``$!_3KW_!H`"3`T```(5&G^_]@P"```%+HU0?0`"``
MIW0`".O?\0@`!,#T____M<`0O__K[KD"`!&GA/_U#>&G]/_RZV_P,``DP-``
M`"$UI_O\V+)/`!#K$0`@``VR3P`104#PH$'`(#BY!``TIUD`"-('\R`0*.,0
MP```!.L!`"``#.,0T"``@.,`,```).,0,`@`)$'`P`BG.P`0IU?_[4%0\J#C
M$$!```3C$$!H`(+C$$`0`(+C$$```(+K,0`?``SK$0`!``VY@0`3XQ#0(`"`
MXQ!`@``DITL`"+D@`$6G=/_BXU`@```$XP`@"``$ZS4`&P`,ZQ4`!0`-XW`@
M(``$I\G__[F!`!/C</"@``BY@@#`N00`,.,P(!``@.-PT!@`"./`(!@`@+F!
M`,/K0``>``VY&@!QZY```@`,N00`%[F!`)2Y!`!\XY#0(`"`N0@`<:<9__^Y
M@@`5N00`J;F``*7C$"`0`("Y!`!'X[`@&``$XT#0(`"`X[#PJ``(N00`,;D$
M`!KCL-`8``CKA``;``RY@0`3Z\0`!0`-N8$`R.LU`!X`#;D(`!OKI0`"``RY
M&@`<N8$`HZ<Y___CH-`@`("Y@@`TN00`L>/`(!``!..PT"``@+F``'JY@``Y
MX\#PL``(X\#0&``(ZVL`&P`,N8$`-^N+``4`#>MT``(`#.M$`!X`#;F!`(:Y
M"``\N8$`1Z=Y___C0-`@`("Y&@`XN8(`>[F``!2Y@`!ZXV#0&``$N00`P^/`
MT"``@.-@\+@`"+D$`(&Y!``7N0@`EKF!`!CK;``;``SK>P`"``SKC``%``WK
MNP`>``VY@0"&N0@`&;F!`+>G>?__X[#0(`"`N1H`&+F"`'RY@``[N8``=.-@
MT!@`!+D$`)'CD-`@`(#C8/#```BY!`"#N00`-[D(`*:Y@0`XZVD`&P`,ZWP`
M`@`,ZXD`!0`-Z\P`'@`-N8$`AKD(`#JY@0#'IWG__^/`T"``@+D:`#BY@@!Y
MN8``'+F``'OC8-`8``2Y!`"CXZ#0(`"`XV#PR``(N00`@;D$`!?K>0`"``SK
MF0`>``VY"`!&N8$`E[F!`!CK:@`;``SKB@`%``VY@0"&N0@`%*=Y__^Y!`!)
MXT#0(`"`N1H`&+F"`'JY@``TN8``?.-@T!@`!+D$`)'CD-`@`(#C8/#0``BY
M!`"#N00`-^MZ``(`#.NJ`!X`#;D(`+:Y@0"GN8$`..MI`!L`#.N)``4`#;F!
M`(:Y"``[IWG__[D$`+KCL-`@`("Y&@`XN8(`>;F``!NY@`!TXV#0&``$N00`
MH^.@T"``@.-@\-@`"+D$`(&Y!``7ZWD``@`,ZYD`'@`-N0@`QKF!`)>Y@0`8
MZVH`&P`,ZXH`!0`-N8$`AKD(`!RG>?__N00`R>/`T"``@+D:`!BY@@!ZN8``
M/+F``'OC8-`8``2Y!`"1XY#0(`"`XV#PX``(N00`@[D$`#?K>@`"``SKJ@`>
M``VY"`!&N8$`I[F!`#CK:0`;``SKB0`%``VY@0"&N0@`-*=Y__^Y!`!*XT#0
M(`"`N1H`.+F"`'FY@``4N8``?.-@T!@`!+D$`*/CH-`@`(#C8/#H``BY!`"!
MN00`%^MY``(`#.N9`!X`#;D(`+:Y@0"7N8$`&.MJ`!L`#.N*``4`#;F!`(:Y
M"``;IWG__[D$`+GCL-`@`("Y&@`8N8(`>KF``#NY@`!TXV#0&``$N00`D>.0
MT"``@.-@\/``"+D$`(.Y!``WZWH``@`,ZZH`'@`-N0@`QKF!`*>Y@0`XZVD`
M&P`,ZXD`!0`-N8$`AKD(`#RG>?__N00`RN/`T"``@+D:`#BY@@!YN8``'+F`
M`'OC8-`8``2Y!`"CXZ#0(`"`XV#P^``(N00`@;D$`!?K>0`"``SKF0`>``VY
M"`!&N8$`E[F!`!CK:@`;``SKB@`%``VY@0"&N0@`%*=Y__^Y!`!)XT#0(`"`
MN1H`&+F"`'JY@``TN8``?.-@T!@`!+D$`)'CD-`@`(#C8/$```BY!`"#N00`
M-[D(`+:Y@0`XZVD`&P`,ZWH``@`,ZXD`!0`-ZZH`'@`-N8$`AKD(`#NY@0"G
MIWG__^.@T"``@+D:`#BY@@!YN8``&KF``'3C8-`8``2Y!`"#XX#0(`"`XV#Q
M"``(N00`L;D$`!?K>0`"``SKF0`>``VY"`#&N8$`E[F!`!OK:``;``SKN``%
M``VY@0!KN0@`'+D$`+FG>?__X[#0(`"`N1H`%KF"`'BY@``[N8``>N-@T!@`
M!+D$`)'CD-`@`(#C8/$0``BY!`##N00`-[F!`#RY"`!&Z\D`!0`-ZVD`&P`,
MN8$`;.MX``(`#+D(`$.Y&@!&ZX@`'@`-N00`QZ=I__^Y@0#(N8(`:>,PT!@`
M!./`T"``@.,P\1@`"+F``&NY!`"$XX#0(`"`N8``'+D(`*.Y!``VN8$`,>MX
M``4`#>MI``(`#.L8`!L`#.N9`!X`#;F!`!>Y"`"CN8$`EN.0T"``@+D:`*&G
M>?__N8``2;D$`!JY@@!XXS#0&``$XS#Q(``(N8``?+D$`*2Y!`!!XT#0(`"`
MN0@`L[D$`#?K>``"``SKB``>``VY@0"'N8$`.NMD`!L`#.ND``4`#;F!`&JY
M"``[N00`J*=Y___CH-`@`("Y&@`VN8(`=+F``!JY@`!YXV#0&``$N00`L^.P
MT"``@.-@\2@`"+D$`(&Y!``7N0@`QKF!`!CK:P`;``SKBP`%``VY@0"&ZW0`
M`@`,N0@`'.M$`!X`#;D:`!BY@0!'IXG__^-`T"``@+F"`(NY@``TN8``BN-@
MT!@`!+D$`''C<-`@`(#C8/$P``BY!`##N00`.+D(`):Y@0`\ZV<`&P`,Z\<`
M!0`-ZXL``@`,Z[L`'@`-N8$`QKD(`#FY@0"+IVG__[D:`#RY@@!GN00`N./`
MT!@`!..PT"``@+F``&3CP/$X``BY!`"3XY#0(`"`N8``&[D(`,JY!`"FN8$`
MH>MI`!L`#.L9``4`#;F!`&&Y"`#*ZQ<`'@`-ZZ<``@`,N8$`H;D:`,;C$-`0
M``2Y@@"*XQ#Q0``(N00`?.-PT"``@+F"`#BY"``4ZV<`&P`,N1H`$^N'``4`
M#>LY``(`#.N9`!X`#;F!`#FY@0"&N1H`&+D$`)/C0-`0``2Y@@":XT#Q2``(
MN00`@>.`T"``@+F"`,FY"`"TN1H`O.MH`!L`#.N8``4`#;F!`):Y!`!+N1H`
M2>O'``(`#.NW`!X`#;D$`)3CD-`@`("Y@0"\X\#0$``$X\#Q4``(N00`>[F"
M`'.Y@@`7N1H`RKD:`,'K>0`;``SKJ0`%``VY!``<Z\@``@`,ZX@`'@`-N8$`
MR+F!`*?C@-`0``2Y&@`:XX#Q6``(N00`?+F"`'NY&@"#N00`H>.@T"``@+F"
M`$>Y!``XZWH`&P`,N1H`-.N*``4`#>M)``(`#.N9`!X`#;F!`$FY@0"'N1H`
M.+D$`'3C@-`0``3C@/%@``BY@@!\N00`D^.0T"``@+F"`'&Y!``8N1H`&^N)
M`!L`#.NY``4`#;F!`(OKN@`"``SKJ@`>``VY@0"ZN1H`%[D:`!BY!`![XX#0
M$``$XX#Q:``(N8(`=+D$`*'CH-`@`("Y@@!SN00`.+D:`#SKB@`;``SKR@`%
M``VY@0",Z\D``@`,ZYD`'@`-N8$`R;D:`#>Y&@`XN00`?..`T!``!..`\7``
M"+F"`'NY!`"3XY#0(`"`N8(`<;D$`!BY&@`4ZXD`&P`,ZTD`!0`-N8$`A.M*
M``(`#.NJ`!X`#;F!`$JY&@`7N1H`&+D$`'3C@-`0``3C@/%X``BY@@!\N00`
MH>.@T"``@+F"`'.Y!``XN1H`.^N*`!L`#.NZ``4`#;F!`(OKN0`"``SKF0`>
M``VY@0"YN1H`-[D:`#BY!`![XX#0$``$XX#Q@``(N8(`=+D$`)/CD-`@`("Y
M@@!QN00`&+D:`!SKB0`;``SKR0`%``VY@0",Z\H``@`,ZZH`'@`-N8$`RKD:
M`!>Y&@`8N00`?..`T!``!..`\8@`"+F"`'NY!`"AXZ#0(`"`N8(`<[D$`#BY
M&@`TZXH`&P`,ZTH`!0`-N8$`A.M)``(`#.N9`!X`#;F!`$FY&@`WN1H`.+D$
M`'3C@-`0``3C@/&0``BY@@!\N00`D^.0T"``@+F"`'&Y!``8N1H`&^N)`!L`
M#.NY``4`#;F!`(OKN@`"``SKJ@`>``VY@0"ZN1H`%[D:`!BY!`![XX#0$``$
MXX#QF``(N8(`=+D$`*'CH-`@`("Y@@!SN00`.+D:`#SKB@`;``SKR@`%``VY
M@0",Z\D``@`,ZYD`'@`-N8$`R;D:`#>Y&@`XN00`?..`T!``!..`\:``"+F"
M`'NY!`"3XY#0(`"`N8(`<;D$`!BY&@`4ZXD`&P`,ZTD`!0`-N8$`A.M*``(`
M#.NJ`!X`#;F!`$JY&@`7N1H`&+D$`'3C@-`0``3C@/&H``BY@@!\N00`H>.@
MT"``@+F"`'.Y!``XN1H`.^N*`!L`#.NZ``4`#;F!`(OKN0`"``SKF0`>``VY
M@0"YN1H`-[D:`#BY!`![XX#0$``$XX#QL``(N8(`=+D$`)/CD-`@`("Y@@!Q
MN00`&+D:`!SKB0`;``SKR0`%``VY@0",Z\H``@`,ZZH`'@`-N8$`RKD:`!>Y
M&@`8N00`?..`T!``!..`\;@`"+F"`'NY!`"AXZ#0(`"`N8(`<[D$`#BY&@`T
MZXH`&P`,ZTH`!0`-N8$`A.M)``(`#.N9`!X`#;F!`$FY&@`WN1H`.+D$`)3C
M@-`0``3C@/'```BY@@"<N00`<^-PT"``@+F"`)&Y!``8N1H`&^N'`!L`#.NW
M``4`#;F!`+BY&@`9ZXH``@`,ZZH`'@`-N8$`BKD:`!OCL-`0``3CL/'(``BY
M!`"8N00`H>.@T"``@+F"`)2Y&@"\N8(`.;D$`,OKF@`;``SKN@`%``VY&@##
MN00`.;F!`#OKEP`"``SK=P`>``VY@0"7N1H`P[D$`'GCL-`0``2Y!``\XS#0
M(`"`N8(`>..P\=``"+F"`!>Y&@"TZW,`&P`,ZT,`!0`-N1H`L;D$`!>Y@0`4
MZTH``@`,ZZH`'@`-N8$`2KD:`+&Y!`!TXZ#0$``$XZ#QV``(N8(`>;D$`!OC
M$-`@`("Y@@!\N00`RNNC``(`#.LS`!X`#;F!`*.Y&@#(ZV$`&P`,ZX$`!0`-
MN8$`AKD:`,>Y!`!ZN8$`=+D:`,BY@`"WXS#0"``$N00`>KD$`(SC@-`@`("Y
M@`!TXS#QX``(N8$`>[D:`#GK:``;``SKN``%``WKD0`"``SK$0`>``VY@0"1
MN8$`MKD:`#>Y&@`[N00`N;F!`+KC$-`(``2Y@`#+XQ#QZ``(N00`N;D$`'/C
M<-`@`("Y@`"ZN1H`%.M(``(`#.N(`!X`#;F!`$BY@0"\ZV<`&P`,Z\<`!0`-
MN8$`QKD$`&2Y@0!IN8``-KD$`&2Y&@`;N8``:;D:`!RY@0!CZS<``@`,ZW<`
M'@`-N8$`-^.PT`@`!+D$`('C@-`@`(#CL/'P``BY!`!SN8$`=+D:`+KKR``%
M``WKJ``;``RY@0#*N8``%[D:`+:Y!`!SN1H`O+F``'3CP-`(``2Y@0!QX\#Q
M^``(N00`J^L8``(`#.N(`!X`#;F!`!CCH-`@`("Y&@#)ZVH`&P`,N1H`Q^N:
M``4`#;D$`'&Y@0"6N8$`<[F``+>Y&@#)N00`<>.`T`@`!+F``'/C@/(```BY
M!`"<XY#0(`"`N8$`>[D:`(3KN@`"``SKJ@`>``VY@0"ZZVD`&P`,N00`2.N)
M``4`#;F!`(:Y!`!KN8$`8;D:`$>Y@`#&N1H`2+D$`&OC<-`(``2Y@`!AXW#R
M"``(N00`A..`T"``@+F!`&RY&@!SZ\D``@`,ZYD`'@`-N8$`R;D:`';KJ``;
M``SK.``%``VY@0`ZN00`I[D$`'RY@0![N1H`H[F``$>Y!`!\N8``>^.0T`@`
M!+D$`#KC,-`@`("Y@0!TXY#R$``(ZT@``@`,ZX@`'@`-N8$`2+D:`)'K8P`;
M``SK$P`%``VY@0`6N1H`E[D$`'2Y&@"1N8$`?+F``'JY!`"$XZ#0"``$N00`
M&>,0T"``@+F``(SCH/(8``CK8P`"``SK,P`>``VY@0!CN8$`A[D:`*OK,0`%
M``WKL0`;``RY@0`[N1H`J+D$`+:Y&@"CN8$`M.,PT`@`!+F``)OC,/(@``BY
M!`"VN8``M+D:`#RY!`#*X\#0(`"`N8$`N;D:`#OKG``;``SKO``%``VY@0";
MZ[$``@`,ZQ$`'@`-N8$`L;D:`#FY!`";N8$`EN,0T`@`!+F``)KC$/(H``BY
M!`"+N00`H^.@T"``@+F``(:Y&@`4ZTP``@`,Z\P`'@`-N8$`3+F!`(GK>@`;
M``SKF@`%``VY@0"7N00`=+F!`'NY&@`8N8``-[D:`!FY!`!TN8``>^/`T`@`
M!+D$`)'CD-`@`("Y@0!SX\#R,``(ZSH``@`,ZZH`'@`-N8$`.KD:`,;KB0`%
M``WK:0`;``RY@0"&N1H`Q[D$`'.Y&@#(N8$`=..`T`@`!+F``!?C@/(X``BY
M!`!SN00`K..@T"``@+F``'2Y&@"+N8$`<>MJ`!L`#+D$`+CK&0`"``SKB@`%
M``WKF0`>``VY@0`9N8$`AKD:`+>Y&@"XN00`@;F!`(.Y@`",N00`<>/`T`@`
M!+D$`)OCD-`@`("Y@`!SX\#R0``(N8$`>+D:`,3K:0`;``SKB0`%``WK2@`"
M``SKJ@`>``VY@0!*N8$`AKD:`,>Y&@#(N00`A+F!`(&Y@`"+X[#0"``$X[#R
M2``(N00`=+D$`*SCH-`@`("Y@`!QN1H`L^LY``(`#.N9`!X`#;F!`#FY@0!X
MZVH`&P`,ZXH`!0`-N8$`AKD:`+>Y!`"3N1H`N+F!`)2Y@`"<N00`<^/`T`@`
M!+D$`(OC@-`@`("Y@`!TX\#R4``(N8$`>;D:`,'K:``;``SKF``%``WK&@`"
M``SKJ@`>``VY@0`:N8$`EKD:`,>Y&@#)N00`<>.0T`@`!+F!`'/CD/)8``BY
M@`"WN1H`E+D$`'&Y!`"LXZ#0(`"`N8``<[D$`$GKF``"``SKB``>``VY@0"8
MN8$`>^MJ`!L`#.NZ``4`#;F!`+:Y&@!'N00`B;D:`$NY@0"!N8``C+D$`'GC
MP-`(``2Y!`"TX[#0(`"`N8``<>/`\F``"+F!`'BY&@##ZVL`&P`,ZXL`!0`-
MZSH``@`,ZZH`'@`-N8$`.KF!`(:Y&@#'N1H`R+D$`(.Y@0")N8``A+D$`'/C
MH-`(``2Y!`!,XT#0(`"`N8``>>.@\F@`"+F!`'BY&@"AZV0`&P`,ZX0`!0`-
MZQL``@`,Z[L`'@`-N8$`&[F!`(:Y&@"GN1H`J+D$`(&Y@0"#N8``C+D$`''C
ML-`(``2Y!`#*X\#0(`"`N8``<^.P\G``"+F!`(>Y&@"YZW0``@`,ZVP`&P`,
MZYP`!0`-ZT0`'@`-N8$`1[D:`+BY@0"6N1H`N;D$`)2Y@0"1N8``FKD$`'3C
MH-`(``2Y!`"+XX#0(`"`N8``<>.@\G@`"+F!`'FY&@"CZY@`&P`,ZS@`!0`-
MN8$`D[D:`*?K/``"``SKS``>``VY@0##N1H`J>,PT```!.,P\H``"+D$`'RY
M!`":XY#0(`"`N8(`=+D:`#&Y@@"WN00`$^MY`!L`#.LY``4`#;D:`!NY!`"W
MN8$`L^LX``(`#.N(`!X`#;F!`#BY&@`;N00`<^.PT```!+D$`('C@-`@`("Y
M@@!\X[#RB``(N8(`I[D:`+3K>``;``SK2``%``VY&@"ZN00`I[F!`*3K20`"
M``SKF0`>``VY@0!)N1H`NN.@T```!..@\I``"+D$`'2Y@@!SN1H`K+D$`)OC
MD-`@`("Y@@`7N00`RNMY`!L`#+D:`,'KJ0`%``WK&``"``SKB``>``VY@0`8
MN8$`I[D:`,JY!`!QXX#0```$XX#RF``(N8(`=+D$`*SCH-`@`("Y@@![N00`
MN+D:`+/KB@`;``SK.@`%``VY@0"#ZSD``@`,ZYD`'@`-N8$`.;D:`+>Y&@"X
MN00`<^.`T```!..`\J``"+F"`'&Y!`";XY#0(`"`N8(`?+D$`,BY&@#$ZXD`
M&P`,ZTD`!0`-N8$`A.M*``(`#.NJ`!X`#;F!`$JY&@#'N1H`R+D$`'3C@-``
M``3C@/*H``BY@@!SN00`K..@T"``@+F"`'NY!`"XN1H`L>N*`!L`#.L:``4`
M#;F!`('K&0`"``SKF0`>``VY@0`9N1H`M[D:`+BY!`!QXX#0```$XX#RL``(
MN8(`=+D$`)OCD-`@`("Y@@!\N00`R+D:`,/KB0`;``SK.0`%``VY@0"#ZSH`
M`@`,ZZH`'@`-N8$`.KD:`,>Y&@#(N00`<^.`T```!..`\K@`"+F"`'&Y!`"L
MXZ#0(`"`N8(`>[D$`+BY&@"TZXH`&P`,ZTH`!0`-N8$`A.M)``(`#.N9`!X`
M#;F!`$FY&@"WN1H`N+D$`'3C@-````3C@/+```BY@@!SN00`F^.0T"``@+F"
M`'RY!`#(N1H`P>N)`!L`#.L9``4`#;F!`('K&@`"``SKJ@`>``VY@0`:N1H`
MQ[D:`,BY!`!QXX#0```$XX#RR``(N8(`=+D$`*SCH-`@`("Y@@![N00`N+D:
M`+/KB@`;``SK.@`%``VY@0"#ZSD``@`,ZYD`'@`-N8$`.;D:`+>Y&@"XN00`
M<^.`T```!..`\M``"+F"`'&Y!`";XY#0(`"`N8(`?+D$`,BY&@#$ZXD`&P`,
MZTD`!0`-N8$`A.M*``(`#.NJ`!X`#;F!`$JY&@#'N1H`R+D$`'3C@-````3C
M@/+8``BY@@!SN00`K..@T"``@+F"`'NY!`"XN1H`L>N*`!L`#.L:``4`#;F!
M`('K&0`"``SKF0`>``VY@0`9N1H`M[D:`+BY!`!QXX#0```$XX#RX``(N8(`
M=+D$`)OCD-`@`("Y@@!\N00`R+D:`,/KB0`;``SK.0`%``VY@0"#ZSH``@`,
MZZH`'@`-N8$`.KD:`,>Y&@#(N00`<^.`T```!..`\N@`"+F"`'&Y!`"LXZ#0
M(`"`N8(`>[D$`+BY&@"TZXH`&P`,ZTH`!0`-N8$`A.M)``(`#.N9`!X`#;F!
M`$FY&@"WN1H`N+D$`'3C@-````3C@/+P``BY@@!SN00`F^.0T"``@+F"`'RY
M!`#(N1H`P>N)`!L`#.L9``4`#;F!`!BY&@#'N1H`P>L:``(`#.NJ`!X`#;F!
M`!JY!`!QXX#0```$XX#R^``(N8(`=+D$`*SCH-`@`("Y@@![N00`N+D:`+/K
MB@`;``SK.@`%``VY@0"#N1H`M^LY``(`#.N9`!X`#;F!`#FY&@"XN00`D^.`
MT```!+D$`'OC<-`@`("Y@@"1XX#S```(N8(`R;D:`(3KEP`;``SK1P`%``VY
M@0!)N1H`C.O*``(`#.NJ`!X`#;F!`,JY&@"$XZ#0```$N00`3+D$`)CCD-`@
M`("Y@@!#XZ#S"``(N8(`M+D:`*'K20`;``SK&0`%``VY@0`4ZT<``@`,ZW<`
M'@`-N8$`1[D:`*NY&@"AN00`=.,0T```!+F"`'SC$/,0``BY!`"ZX[#0(`"`
MN8(`A[D:`!/K>P`;``RY&@`8ZSL`!0`-ZXD``@`,ZYD`'@`-N8$`-[F!`(FY
M&@`3N00`>.,PT```!.,0T"``@+F"`'3C,/,8``BY@@"GN1H`/.MQ`!L`#.O!
M``4`#;)/`)"Y&@`ZN8$`Q^N9`"``#;D:`#SKJP`"``SCP"`@``3KNP`>``VR
M3P"1N1H`Q+D:`%.Y@0"ZXT`@&``$XS`@$``$N0@``;D:`$BY&@`[N00`%>/`
MT"``@.,`T"``@.-`T"``@.,0T"``@.,PT"``@./`("``).,`(`@`).-`(!@`
M).,0(```).,P(!``)-4'\R"0**=T``GC0/.8``3K;_-8``0'],#E___L2^M_
M\#@`)*?[_V"Y`@"2IX0`3<`0``!&<^-P$```!+D"`'>GA`!#XQ"0``"0$A&Y
M!`"#IX0`5*<>`#VGA`!0N00`J4&@H`'C$*```)`2$:>$``:G'@`]IW3_]ANI
MX\!P```$N0(`S*>$`"&Y%`"JN00`M[D$`"RY!``YN00`2L#E___NN1(BIW0`
M"$$:P`"5/1``IX0`%$&PL`CCP+````2Y`@#,IW3_Y^-`\1``!*<I``#K?_#8
M``0']+D)`+?K&P`#``I0$(``XT#Q$``$02K``>M_\-@`!`?TIZ@``*?T_[\'
M!P<'!P>R3P`0ZQ$`(``-Z\_P8``DLD\`$:?[_U"Y!`#2P,```$7ZT@?PJ!`H
MN00`+4$P\*3`Y?___W2Y`@`BIX0`+.,0\*0`%.L1``,`#>,0P```".,P$`@`
M!.,P$```)+D"`#.GA/_D01`0".,P$`@`!.,P$```)+D"`#.G=/_VN00`+4$P
M\*3`Y?___TJY`@`BIW3_V+)/`!#K$0`@``VR3P`1U0?PJ!`HIW0`">-`\2``
M!.O/\1``!`?TP.7__^MX!P?K;_`P`"3`T```$?&G^_](LD\`$.L1`"``#;D$
M`%.R3P`1XS`P``"05S#0#*=(```?0[D$`#7C,-```(BY!`!#XS#PH``DT@?P
ML!`HN00`%*<(``"GF0``03#PK+D$`,*R7@"1IQ3__KD)`)3`Y?___O:Y`@`B
MIX0`LKD$`#*G"```IQD``+)>`!.G%/_^N0D`$KDQ`!FGI`"06+#PK,"@``!%
M6>,0P```D!(1IX0`^*<>`#VGA`#TN00`'*?T``:G/@`]IX0`"D$0$`'C,!``
M`)`2,Z=T__8;'*>:``(8*1HAN18`N^N[``,`#;D6`"+CL*````C`Y?__Z\GC
M(+```"2Y`@`BP!```$4EIX0`TN,P\*P`%NLS``,`#>-`$```!.,0P```D$$@
MP`'C0T````1"$$``5!#0"*=T`!&G]``304!``>,0(```D$(00`!4$-`(IX0`
M"*<K``&G'@`]IW3_\9(]0`"G&0``XR#PH``$XR$@``"00B%``:<;``&Y`@`B
MIW3_]*<H``"R3P`0ZQ$`(``-LD\`$;D4`"+5!_"P$"BG=`"*XT#Q*``$ZV_P
MZ``$!_2G&0``XS#PH``$XS$P``"00C$@`*<;``&Y`@`SIW3_]*?T_]G`H```
M1+OC<*````35!]``<`"GA`!<N00`%Z>X``!!$!`(I[H``=4'T``0`*=T__D8
M.Z<Z``*Y%``SZS,``P`-P!```$RWOR\0`*>$`!ZY!``GP.7__^I^XR"@```D
MN0(`(J>$`#JY%`"+IXL``>L8``,`#:<Y``#C,2```"10L/"LI_3_)+D$`".G
M.``!4#`0`,#E___K#KD"`&*GA``=N10`B[D$`#?K2``#``W`Y?__Z;#C8*``
M`"2Y!``FI_3_UJ<8``"G]/\=ISD`$*>X``"G]/^WIRC__Z?T_VS`Y?__ZA@'
M![)/`!#K$0`@``WK;_`P`"2R3P`1I_O^P+D"`-+2!_$X$"BGA``&E0#0`*=T
M`!6R3P`0ZQ$`(``-LD\`$=4'\3@0**=T`)GC0/&P``3K;_%P``0'],#E___M
M"KD"`+*GA/_HN00`*\#E___L@;D"`!*GA`!AE2X0$Z>$`&E!$!`3N00`P;D$
M`!VY!``\IP@``*<I``"Y!`!MLEX`(:<4__ZG&0``LEX`$Z<4__ZY"0`<N0D`
M+1HAIRH``KD4`"+`Y?__ZH6G.0`!ITG__\!0```1"N/`\*``)+D$`*+`Y?__
MZQ:Y!``ZIRD``4%`\*C`Y?__[&VG+O__N00`*J>$``JE'_``5!#PP*<>0`"G
MA``OP.7__^I,N00`*L#E___I%[D$`"O`Y?__["*Y`@`2IW3_H[D$`"O`Y?__
M['FY!``MP.7__^E$I_3_=.,@$!0`D!(BIX3_B*<N`"ZG=/^1E0`0%:>$_X"G
M]/^+P.7___]+I_3_T\#E___I6@<'!P<'!^NO\%``),#0```/V:?[_V#`H```
M0XCC(*```!;`Y?__[";C$"#@``3C(*```!;CL!`(``3`Y?__[!JG.`!_XQ`@
MK0"0%#'C(*```!88P\#E___L#>,0(`@`!.,0$"``!.L1`#<`#(D0``<6'$`0
ML`+C(*```!;`Y?__Z_GC$"#@``3C(*```!;CP!`(``3`Y?__Z^W`,```$=>G
M20``P.7__^I5XR#`*``DXR"@```6P.7__^O<XQ`@X``$XR"@```6X\`0"``$
MP.7__^O0XQ`FB``$XQ#`,``DXR"@```6P.7__^O$XQ`@X``$XR"@```6X\`0
M"``$P.7__^NXU0?0`"&`IX0`4N,@H```%L#E___KK>,0(8``!.,0$*@`!.,0
MP#@`).,@H```%L#E___KGN,0(.``!*<Y``#C(*```!;C$!`(``3C,!!``"3`
MY?__ZXWC$"#@``2G.0``XR"@```6XQ`0"``$XS`0(``DP.7__^M\XQ`@X``$
MXR"@```6X\`0"``$P.7__^MPXQ`C.``$XQ#`2``DXT#Q$``$ZZ_P\``$!_2G
M&0``I_3_NNN_\%@`),#0```/!:?[_V#`$```0K"Y!`#"XR`0```6N00`L<#E
M___K2D$@(9BY!`!"N00`/*<I``'`Y?__ZT\2(J>$``VG*```XT#Q$``$N10`
M(NN_\/@`!`?TXR"P```6P.7__^LKI1_P`%00(;"G'D``IX0`$.,@L```%L#E
M___K':4?\`!4$"&P61#0`*=T_]NY!``LISD``L#E___J;A`BIRK__X@@`!_C
M0/$0``2Y%``BZ[_P^``$!_0'!^N_\%@`)+)/`!"G^^]8IUD0H.L1`"``#;)/
M`!&Y!`#"N00`LT%5\`#`(```#V=!,/"@ITD/_]('4``0*,#E___H;A(BI\0`
M2Q@2IQK__[D4`-'C/?"@`)"G,0#_IX0`/+D4`-)!(/"@ISD`+[D$`$W`Y?__
MZ;2Y`@`BIX0`,,`0``!"&>,@$```%L#E___JM[D$`#Q!0/"@N00`7<#E___J
M3K)/`!"G*1"@ZQ$`(``-LD\`$4$B\`#5!R``$"BG=``@I_L0J.-`\'``!.N_
M\%@`!`?T$A&G=/_'P!```$'KXR`0```6P.7__^J)N00`/+D$`$O`Y?__Y^*G
M]/_4P.7__^>=!P<'!\`0``!!U.OO\'``).,@$```%J?[_V#`Y?__ZFW`,```
M#O'`0/__YT?`4```#MCK[_$0``3`]/__Z0X'!P<'!P?K;_`P`"3`T```0;&G
M^_]8XR#0```6P.7__^I-P.7____2XR#0```6P.7__^I$P&```!`NIQD``.,0
M\*``),!````*?;D$`%;`,```#LG`Y?__Z8'C0/$8``3K;_#8``0']`<'!P<'
M!^MO\#``)+)/`!"G^]](IRD@L.L1`"``#;)/`!%!(O``T@<@`!`HP.7__^?A
MP!````ZTN00`8N,0\*``)$$@\*ZG.0`!ITD0`<!0```.H,#E___HC1(BIT0`
M5Z<9$*]!(/"NITD0`$$Q\`#`Y?__YW\2(KD$`-*G1`!'IRH``;D4`"+`Y?__
MY].Y`@`BIX0`/+D4`-T2W:=T`!]!'2``D@`0`+)/`!"G.2"PZQ$`(``-LD\`
M$4$S\`#5!S``$"BG=``RI_L@N.-`\'``!.MO\#``!`?T&#VG&1"OISK__QA#
MB$``"!)$01'P`+D$`%*G=``/P$`````;N18`,T0P0`"G]/_-IRD``*?T_\W2
M_U``$`!!4%$`01`1`*=&__FG]/_JP.7__^:ST@!0`!``!P?`]/___V@'!^MO
M\#``),#0```--:?[[T"R3P`0ITD0N.L1`"``#;)/`!&Y!`#"N00`HT%$\`!!
M,/"TP"````X8T@=``!`HP.7___I!ISD`+[D$`+*Y!``LP.7__^>0N0(`(J>$
M`"7`(```#@>Y!``\P.7___L`N00`++)/`!"G.1"XZQ$`(``-LD\`$4$S\`#5
M!S``$"BG=`#+I_L0P.-`\'``!.MO\#``!`?TN00`'*<(``"Y!``JIZD``,`P
M```-X[)>`*&G%/_^&!H;'!BAP.7__^B4N0(`(J>$_\:GJ@`!IXGP`)4`(`"G
M=``%P"````V]N0(`NZ>$``ZY!``2N00`.Z<(``"R70`3IQ3__J>$`&>Y!``R
MIP@``*<9``"R7@`3IQ3__KD)`!*Y!``RN1@`,4$SC_^5+S``IW0`$*<:__^Y
M%``Q04,@`$$TC_^2`$``E2\P`*>$__0:&J<>#_^G)/^"P!````V/XQ#PH``D
MISD``:=)$`#`4```#A*Y!`!BX\#PJ``D02#PN,#E___G5<"0``!`'N,@D```
M%L#E___HO$$@(9BY!`!"03#PN*<I``'`Y?__Z*$2(J=T`!#C()```!;`Y?__
MZ*BE'_``5!`AL%D0T`"GA``0IRD``,`P```-4,#E___H"+D"`"*G=/]ZI_3_
M.$$@\+BG.0`!P.7__^?K$B*G=/_J03#PN,`@```-,<#E___Z+$$@\+C`Y?__
MYTNG]/\IP.7__^66!P<'!P<'P%````PDXQ`@``"0N0(`$0>.&$%!$"`!I_0`
M#.,P$```D*<;``&Y`@`S&$.GA``2O4%0`*=T__3C,!```)"Y!``AIQL``;D"
M`#,80Z=T__('_@<'!P<'!^O?\&@`),#0```+^:?[_V"Y`@`RIX0`8.,@,```
MD+D"`"*GA`!9N00`0Z<(``"G&0``LEX`%*<4__ZG&___N2$`,:>D``Z5+Q``
MIW0`7;D$`$&Y"0!#IQO__Z='`%&Y(``QIX0`-;D$`$&Y!``AN0D`0Z<K__^Y
M(0`RIR0`>:<___^GA`!UIQO__Z='`%.Y"0`3N00`(:<K``+C(-```"&G)`!4
M04`0`<`@```_8*=9$`#`Y?__YPOC0/$0``3`(```/U7KW_$(``0']*<O`"^G
M=`!%IRD``L#E___ER+D"`"*GA``SIQ@N`$`0(`#C0/$0``3KW_$(``0'])4O
M$`"GA/^KN00`0;D$`%&Y"0!#IUO__[DA`#6G)``NIS___Z>$`"JG&___IT<`
M"J?T_YF5+Q``IX3_J:?T_ZN5+Q``IW3_\J?T_Y'C0/$0``2G*0``Z]_Q"``$
M!_3`(```#$WKW_$(``3`]/__YF&G20`!I_3_BZ=)``&G]/_6!P<'![)/`!#K
M$0`@``WK[_!P`"2R3P`1I_O_,,`P```+-,`@```,+-('\,@0*-(A\*8P`,#E
M___XN,`@```,)<#E___XLL`@```,(\#E___XK,`@```,(L#E___XIL`@```,
M(,#E___XH,`@```,(L#E___XFL`@```+],#E___XE,`@```,',#E___XCL`@
M```,&\#E___XB,`@```,&L#E___X@L`@```+X<#E___X?,`@```,$\#E___X
M=L`@```,$L#E___X<$$P\*#`(```#!#`Y?__]_2Y`@`RIX0`",`@```+\<#E
M___XOD$P\*#`(```#`?`Y?__]^*Y`@`RIX0`",`@```,!L#E___XK$$P\*#`
M(```#`3`Y?__]]"Y`@`RIX0`),`@```+FL#E___XFL`@```+M,`P```,",#E
M___XD;)/`!#K$0`@``VR3P`1U0?PR!`HIW0`-.-`\4``!.OO\4``!`?T03#P
MH,`@```+WL#E___WHKD"`#*GA``*P"````N:P.7___ALI_3_TD$@\+?`,```
M"].G20`*P.7__^:$$B*G=/_%03#PP<`@```+@\#E___X5:?T_[O`Y?__X\0'
M![)/`!#K$0`@``WKW_!H`"2R3P`1I_O_4,#0```]X%@@T`"G+O__T@?PJ!`H
MIX0`%[)/`!#K$0`@``VR3P`1N10`(M4'\*@0**=T`"_C0/$@``3KW_$8``0'
M],`@```+2D$P\*3`Y?__]T:Y`@`BIX0`%N,0(```D+D"`!&GA``/IRD`,+F"
M`"&Y`P`BZR(`/P`,4"#0`*?T_\VG*```4"#0`*?T_\?`Y?__XVT'!P<'Z^_P
M<``DI_O_8,#E___C<\#E___BT+D"`"*GA``,XR`@```$XT#Q$``$Z^_Q$``$
M!_2G*0``I_3_]P<'!P<'![)/`!#K$0`@``WK;_`P`"2R3P`1I_O_",`P```)
M[-('\/`0*-(W\+@P`./0\+@`!+D"`-VGA`!!N00`HD'`\,"G]``8N00`.L#E
M___B=+D"`"*GA`!%I\L`"+D$`!RG&__XX]`0```$N0(`W:>$`"6Y!``M03#P
MM,#E___VQ+D"`+*GA``&E0"P`*=T_]VY!``MN00`.L#E___WB:?+``BY!``<
MIQO_^./0$```!+D"`-VG=/_?LD\`$.L1`"``#;)/`!'5!_#P$"BG=`!"XT#Q
M:``$ZV_Q*``$!_2Y!``:N00`.Z<(``"Y!`!JLEX`(:<4__ZG&0``LEX`$Z<4
M__ZY"0`;N0D`*D$B$`+`Y?__XY+`$```"E3C$/"@`"3CL/"H`"2G.0`!ITG_
M_\!0```*U;D$`)+`Y?__Y!VY!``MN00`.<#E___W,J?T_X;`Y?__XJ$'!P<'
MZV_P,``DP-````F5X_#0:``(LD\`$.L1`"``#;)/`!'CP-!@``3`4```"57`
M,```"5Y!S/`(P$````EQT@?``!`HTA?PT%``TB_Q`#``N00`PD$P\,S`(```
M"?K2%_#H0`#`Y?__]B.Y`@"RIX0`!I4`L`"G=`)\P.7___[XN0(`HJ>$`G^Y
M!``:IP@``*<I``"R7@`AIQ3__KD)`"KK(@`!``VG*P`!P.7__^,8XQ"@``"0
MN0(`$;D$`+*Y!`"2&&&GA``>5&#0>+D4`&:Y!``IISD``:=)___`4```"D[`
MY?__XYQ!H*`!XQ"@``"0N0(`$4&0D`(88:=T_^;C(/$```2Y`@`B0:#Q"*=T
M`!&G]``KIZL`"+D$`!JG&__XXR`0```$N0(`(J>$`!Y!,/#,P.7___6[N0(`
MDJ>$_^R5`)``IX3_Z,#E___Y?!(BIX3_XKD$`"G`Y?__XZ"Y`@!BIW0`/N.`
M\-``!+D"`(BGA`#$E0"``*>H``'CD-!8``2G=``=I_0`N>,@T%``!+D4`!KK
M$0`#``U!(O`(N0@`$N.!GM@`!+D"`(BGA`"FIZH``94`@`"GA`"@N00`*,#E
M___Y0!(BIX3_X;D$`"C`Y?__XV2Y`@!BIX3_V+D$`!:Y!``KIP@``*>I``"R
M7@"AIQ3__J<9``"R7@`2IQ3__KD)`!NY"0"F&J&GJ@0$N10`JKD$`"K`Y?__
MXF#`$```"2/C$/"@`"3`$```":[C$/"H`"2G.0`!ITG__\!0```)G^.P\+``
M)+D$`)+`Y?__XN6Y!``IISD!P,#E___C#J<N__^GA`!-P+```#NCXR"P```6
MP.7__^1!02`AF+D$`$*Y!``YIRD``<#E___D1A(BIX0`6\`0```[B.-0P```
M!+D$`&GC(!````2G.0`!P$````FIP.7__^-@IRD``+)/`!#K$0`@``VR3P`1
MXS#08``$03/P"-4',``0**=T!$#C\-!(``CC0/!P``3K;_`P``0']*=I``"G
M]/]QP.7__^)\6!`@`*<>`!&GA/^NN10`$<`@```[2>,0\*``).-0P```!+D$
M`&GC("````2G.0`!P$````DKP.7__^,>IRD``*?T_[[C(+```!;`Y?__X]2E
M'_``5!`AL*<>0`"G=/^;XR"P```6P.7__^/&6(`AM,#E___@\1F"IW3_C>,@
ML```%L#E___CN*<8`?]4$"&PIQX!P*=T_W^Y!``JP.7__^&;03#PS+D$`*+`
M(```"-S`Y?__]'FY`@`BIX0#R^.PP```!,#E___B9[D$`#*Y!``KP.7___H(
MN0(`LJ>$`[JY!``KIP@``*<9``"R7@`2IQ3__KD)`!NG'@`#I\0`);D4`"&G
M*__\P#````C=02*P`+)=`#*G%/_^IW0`%J<>``2GA`+_IQK__+D$`"NY&``A
MN00`$J<I\`!!$A__E2\0`*>$`N_`Y?___+82(J=T``^Y!``KISD``,#E___A
MK!(BN00`PAABIW0`ML`P```(8\`@```(%\#E___TZ<#E___A"L`0```'[>,0
M\*``),`0```)'N,@\*@`)+D$`&GC$/"P`"2Y!``JISD``:=)___`4```");`
MY?__X:VGR```I_0`,<#E___AEM4#T'0@`*=T`#3`Y?__X-ZGR@`!XR#PJ``D
MP"````>\N10`'.,@\*``),`@```(Z^,@\+@`).,0\+``)+D$`"JG.0`!ITG_
M_\!0```(;+D$`&G`Y?__X7JY!``JISD!P,#E___AHZ<N__^GA/_(N00`*<#E
M___?BKD$`#K`(```!W[`Y?__]'ZY!``JP.7___REN00`*J?T_JW`Y?___)ZY
M!``KP.7__^&1I_3^HT&P\.C5!]!`L`"GA``AXR"P```$03#PS,#E___SB+D"
M`!*GA``&E0`0`*=T``:GNP`(I_3_Z<#E___A<;D"`**G=/UCI[L`"*?T_]ZG
M*0`-P*````?/I_3]::<Y_^ZG20`"P.7__^`[03#Q\+D$`"RG20`&P.7__]\"
ME0#Q\*=T``:50_'QIX0"9;D$`"RG.0``ITD``,#E___@(>,0T#@`!.,0\3``
M).,0T#``!.,0\3@`).,0T"@`!.,0\4``).,0T"``!.,0\4@`).,0T!@`!.,0
M\5``)*<9``"Y%`!FXQ#Q6``DXQ#Q8``D4!#QJ$$P\?"Y!``FI4^``,#E___>
MOA(BN00`,AB"I\0`LKD4`"/C0/%8``3K$@`#``VY"``4XQ#0$`"`N2$`0>-`
M\6``!*?$``2G2P`!ZR(`'0`,N0@`0N,0\5@`).-`\6``)+\?\:BGA`&?IR@`
M0!LA&3(80Z?$``,80KD4`!&Y%`!TN0(`=T$1\6BGA``=N00`QZ?+___K+``(
M``RY`@`B05#Q\*>$``O2_Q``4`!!$!$`05!1`*<G__G`(````B-$P"``&!1:
M$/&H4!#QJ*<>`$"G=/^8&(-!$/'P02#Q,!N$N0@`<<#E___D)J>.`#^GQ``L
M&!BG&O_`&,&(P``&I\H``1(1N00`MZ=$`?=!(/$PTC_Q:+``0;"P0,#E___D
M"Z?&__:GBO_`&"B((``&N18`$J<;``'K$0`&``V)(``&&X)!<7``N10`2+D$
M`#>G60!(02#Q:,#E___?J4$P\?"Y!``FI4^``%"`\:C`Y?__W@X2(KD$`#(8
M@J<D_U*Y!``FP.7__^&SX\#Q6``$ZQP``P`,5!#0<+D4`#$8(:<J``&G+@`X
MX[#Q8``$03/Q:)*`,`"G)`$KN10`,J<H`#<;(;D4`!*Y`@`102/Q:*>$`!>G
M&___ZS$`"``,N0(`,Z>$``G7_R``(`!!("$`IS?_^\`P```!B400,`#K"P`0
M``SK6P`(``SK3``8``SK/``0``SK'``(``SKBP`8``Q!(/$P0K#QHT+`\:="
M@/&@0@#QH4)0\:)"0/&D0C#QI4(0\:;`Y?__XW;C`/$P``3C4/$X``3C0/%`
M``3K8``0``SKX``(``SK=0`8``SKA0`0``SKM0`(``SK$``8``SKQ``8``SC
M,/%(``3C(/%0``3CP/#``"1"`/&V0F#QM$+@\;5"4/&Z0G#QMT*`\;A"L/&Y
M0A#QLT)`\;[2`/&[\,?KQ``0``SK@@`0``SKL@`(``SK!``(``SK8P`8``SK
MXP`0``SK4P`(``SK<@`8``Q"P/&\0H#QQ$*P\<5"`/&]0C#QPD)@\;]"X/'`
M0E#QP4(@\<9"</'#0;#QQT&`\;2GR0`4IV@`_Q1AN00`*[D4`&:G.0`!ITG_
M_\!0```%Y:>[``+`Y?__WS&GQP`OP!````52XQ#PH``DXQ#04``$N00`*J<Y
M``%!$?`(XQ#0"``(XQ#PJ``DP!````9TXQ#PL``DITG__\!0```%[;D$`&F2
M`/'OP.7__]\(I_3]F4%P\?"G]/ZB0Q"``*>+``&G]/^ZXR#`"``$N0(`(J>$
M_0ZY!``RIP@``*<9``"R7@`3IQ3__KD)`!+C$-```"&GQ/S]IQO__$$1(`#`
M(```!;BR70`AIQ3__J=T_/#CL,`(``2G]/SKN10`(J<X`#\;,1(S&!-!(O%H
MIX0`&*<:__\8,8@P``@2,Z>$``G7_R``(`!!("$`IS;_^\`P````9KD6`!%$
M$#``02#Q,,#E___B<-<W\6CQ:*?T_M"50?'RIW3]FY5#\?.G=/V7E4CQ]*=T
M_9.51?'UIW3]C[D$`"RG.?_&ITD``L#E___=KD$P\?"Y!``LITD`*<#E___<
M=<`0```$J.,0\*``)$$0\?#C$/"H`"3`$```!=2Y!`!IXQ#PL``DN00`*J<Y
M``&G2?__P%````5'P.7__]YFI_3\]^.PP```!*?T_$7`Y?__W.RGR``!I_3^
M"=(`$`!0`-<`(``@`-<`(``@`.MO\#``),#0```$%:?[_TBR3P`0ZQ$`(``-
MLD\`$<"0```W">,@D```%M('\+`0*,#E___?I$$P\*R2`2"IP"````1FP.7_
M__!RN0(`(J>$``:5,2``IX0!6\#E___X"^,@D```%L#E___?B<`P```%1Z=)
M``&G60`+P.7__]U_N0(`(J>$`(+C$"`0``3`@```/NWC<!`H``18$(``IQX`
M`:?$`'.G&``!I\@``%`0\*3`8```/M>G]``;XR`@$``$IP@``+)=`"NG%/_^
MIW0`55@0\*2G&@`!&"&GR@`!4!#PI%@0@``9$J?$`$GC()```!;`Y?__WT*Y
M!``WN10`3*=9``#`Y?__WKFY`@"BIX0`-.,0\*0`%.L1``,`#>,@H```!.-`
M8```!%@PT`14,"`,ISX$`..Q0```!*>$_[_`$```-G?C(!```!;`Y?__WQ7C
M,*````2G20``IUD``L#E___<>Z<(``"R70`KIQ3__J>$_Z]8$(``&"&G*O__
M&2RGA`"KXR"0```6P.7__][UP#````2VITD``:=9``/`Y?__W.NY`@"RP,``
M`#9"IX0`'N,@P```%L#E___>WN,0L!``!,!````$G>,P$```!,#E___<,N,0
ML!``!.,0$```!)%`$`VG=`$EXR"0```6P.7__]["P#````2'ITD``:=9``/`
MY?__W+BY`@"RP*```#8/IX0`'\`@```#7$$P\*S`Y?__[X&Y`@#"XR"@```6
MIX0`O,#E___>G^,0L!``!+D$`$SC,!````3`Y?__V_3C()```!;`Y?__WHY!
M,/"LD@`@J<`@```#,,#E___O7,#````]_;D"`"+C(,```"2Y!`""P*```#73
MIX0`1*<Y`<#`Y?__W3"G+@`1IX0`"1@2IQH``540T`"G)`#<LD\`$.L1`"``
M#;)/`!'5!_"P$"BG=`#-XT#Q*``$ZV_PZ``$!_2G'@`!I\3_5:?(``'C()``
M`!;`Y?__WD:Y!``WP.7__]L!I\H``5G`@`"G1/_QI_3_0)4`(`&GA/ZHI_3^
MH\`0```]I+D$`('C(!````3`Y?__^*SC(,```"2Y`@`BIX0`C^,0L!``!%@@
MT`3C$!````14(!`,IRX$`*=T`%OC(!`0``3CH(````2Y!``ZP.7__]K8XQ"P
M$``$N00`PE@@T`3C$!````3CH*````14(!`,IRX$`*=T`";C0!`0``2Y!``Z
MN00`7,`@```#Q<#E___<B,#E___=Y<`0```]5N,@L!``!.,0$```!.,@(```
M!.,P$```!,#E___RUZ?T_S_C()```!;`Y?__W<OC$+`0``2G20``IUD``N,P
M$```!,#E___;+KD$`$*G]/_*XR"@```6P.7__]VTXQ"P$``$ITD``*=9``+C
M,!````3`Y?__VQ>G]/^7XR#````6P.7__]V?XQ"P$``$XS`0```$P.7__]RF
MI_3^SL`@```#6L#E___<+L#E___:J\`0```\_+D$`%+C$!````2Y!`!(P"``
M``-LXS`0```$P.7__]P8!P?KO_!8`"3`T````=&G^_]@N00`PL#E___U)N,0
M(```D+D"`!&Y!`"RIX0`(1A!01`@`:?T``SC,!```)"G&P`!N0(`,QA#IX0`
M$KU!T`"G=/_TXS`0``"0N00`L:<;``&Y`@`S&$.G=/_RP.7___:?$B*GA``6
MN0(`S*>$`!*5`,``IX0`#KD$`"O`,````G;`Y?__V9RY(`"RIX0`">-`\1``
M!.N_\/@`!`?TN00`+.N_\/@`!,#T___P)0<'!P?KW_!H`"3`T```-&VG^_]@
MXR#0```6P.7__]T)ISG__\#E___:I.,@T```%L#E___<_L`P___PQZ=)``#K
MW_$(``3`]/__W-/`$```-#BY`@`1IX0`#.-0$```!,`0```T(N,0$```!`?Q
MP%```#0GI_3_]@<'!P?KC_!``"2G^_]@N00`HKD$`).Y!`"$P.7__]D-P+``
M`#'JP!```#'CN0D`L>N[``,`"J>$`!*Y!`#1XQ#0```$N00`*KD$`#FY!`!(
MI]L`"`WAI[?_].-`\1``!.N/\.``!`?T!P<'!P?^!P<'!P<'ZV_P,``DN00`
M'Z?[_V#C$/```"3`P```,LX'!^-`\1``!.MO\-``!`?T!P<```````(``0``
M````````````#@````"``-(X`````(``TC@```````````````#*8L'6````
M`(\;O-P`````;MGKH0````!:@GF9`````/____\``````````````/\````]
M`````````````*``````````@```````+P`````````````````0`%]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````````````````@`!MZ@``
M``"``&W2`````(``;=H`````@`!N``````"``&WH`````(``;?H`````````
M``````"``&[P`````(``;.````````````````"``&V6`````(``;9H`````
M@`!N]@````"``&SF`````(``;OX```````````````"``&\"`````(``;P@`
M```````````````````#________?\\`````_____P````##TN'P`````!`R
M5'8`````F+K<_@````#OS:N)`````&=%(P$``````````````````('X````
M````@?#_______]P`````````('H________?@@````_````$0```/\`````
M`````0`@!``O`````````$`_``````````````````!#P```````````````
M````<&5R;'AS:2YC`````````"5S+R5S`"]P<F]C+W-E;&8O97AE``!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M`"]P<F]C+R5I+R5S`&5X90`N`%!!4E]414U0``!005)?4%)/1TY!344``#H`
M+P!015),-4Q)0@``4$523$Q)0@!015),-4]05```4$523$E/``!005)?24Y)
M5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?
M0T%#2$4`4$%27T%21T,``%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`
M`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.``!005)?0TQ%04X]```Q`$Q)0E!!5$@`3$E"
M4D%265]0051(``!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(``!365-4
M14T``"4P,G@``"5S)7,E<R5S``!P87(M```E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L
M```N<&%R```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*```O=&UP``!414U01$E2`%1-4`!54T52``!54T523D%-10``05)'5@``
M&`!P97)L```P`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E
M<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U0
M3$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P
M+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM
M;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N
M86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*
M:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=6
M7S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T[
M"GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I
M9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIS965K(%]&2"P@+3@L(#(["G)E860@7T9(
M+"`D8G5F+"`X.PIL87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*
M<V5E:R!?1D@L("TQ,BP@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(
M+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L
M:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D
M97AT+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@
M)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64[
M"GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B
M)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S
M92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E
M<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME
M>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF
M(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M
M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB
M:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L
M;W-E("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN
M;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")2
M96%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO
M8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\
M)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@
M(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<
M,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?
M<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE
M>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S
M970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H
M*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!S;W)T('L*;&5N
M9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA+T)31%!!3B\*?2!G
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A
M;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE
M<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1
M)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>
M0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN
M960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U
M=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N
M("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^
M.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R
M:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^
M<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R
M:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@
M;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H
M;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@
M>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K
M("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@
M<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%2
M7T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I
M;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF
M("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*
M<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*
M?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH````!
M&P,[````X````!O__WAT```%S/__?'P```#\__^9A````3S__YIL```!C/__
MFRP```&\__^=[````?S__Y]L```"//__H1P```)T__^AW````JS__Z+D```"
MW/__HR0```+\__^CC````SS__Z2\```#?/__I,0```.4__^F]````]3__Z=,
M```#[/__J,P```0T__^JE```!%S__ZM$```$A/__JX0```2L__^LW```!.S_
M_[A<```%+/__O.P```5L__^]K```!:3__[WT```&#/__OB0```8D__^^C```
M!EP````4``````%Z4@`!>`X!&PP/H`$````````\````'/__>W@``!T(`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!4H.R`<#'/`*S\[-S,O*R<C'Q@Z@`4(+````
M````3````%S__YA`````X@!&APV(#(D+B@J+"8P(C0>.!H\%1`[``@*N"L_.
MS<S+RLG(QPZ@`4(+7@K'R,G*R\S-SL\.H`%""P`````````````L````K/__
MF-@```"^`%2,"(T'C@:/!40.T`("G@K/SLW,#J`!0@L````````````\````
MW/__F6@```*^`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.V`(#`:0*S\[-S,O*
MR<C'Q@Z@`4(+````````/````1S__YOH```!>@!4A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5$#N`#>@K/SLW,R\K)R,?&#J`!0@L``````````#0```%<__^=*```
M`;``1HH*BPF,"(T'C@:/!4H.P`(#`98*S\[-S,O*#J`!0@L`````````````
M-````93__YZ@````O@!&BPF,"(T'C@:/!4H.P`("2@K/SLW,RPZ@`4(+`F#+
MS,W.SPZ@`0`````L```!S/__GR@```$$`$J+"8P(C0>.!H\%1`[((@*X"@Z@
M`4S/SLW,RT(+```````<```!_/__H``````Z`%*.!H\%1`[``E[/S@Z@`0``
M`#P```(<__^@(````&(`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[(`@)0S\[-
MS,O*R<C'Q@Z@`0`````````````\```"7/__H$@```$N`$J&#H<-B`R)"XH*
MBPF,"(T'C@:/!40.V$("N`H.H`%,S\[-S,O*R<C'QD(+````````%````IS_
M_Z$X````!@``````````````/````K3__Z$H```"*@!&A@Z'#8@,B0N*"HL)
MC`B-!XX&CP5*#N`B`H8*#J`!3,_.S<S+RLG(Q\9""P```````!0```+T__^C
M&````%(``````````````$0```,,__^C6````7P`1HT'C@:/!4H.P`("N@K-
MSL\.H`%""VX*S\[-#J`!0@L"7`K-SL\.H`%""TP*S\[-#J`!1@L``````"0`
M``-4__^DD````<8`5(X&CP5$#O`"`P%0"L_.#J`!0@L````````D```#?/__
MIC````"L`%2-!XX&CP5$#M`"`D`*S\[-#J`!0@L`````)````Z3__Z:X````
M.@!&C@:/!40.P`)F"L_.#J`!0@L``````````#P```/,__^FT````50`5(8.
MAPV(#(D+B@J+"8P(C0>.!H\%1`Z8`P+""L_.S<S+RLG(Q\8.H`%""P``````
M```\```$#/__I^@```N``$:&#H<-B`R)"XH*BPF,"(T'C@:/!4P.F(4"`P+8
M"@Z@`4S/SLW,R\K)R,?&0@L`````/```!$S__[,H```$C@!&A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5*#M@"`P+("L_.S<S+RLG(Q\8.H`%""P```````#0```2,
M__^W>````+P`1HL)C`B-!XX&CP5*#L`"`IH*S\[-S,L.H`%""TK/SLW,RPZ@
M`0``````)```!,3__[@`````2`!&C0>.!H\%2@[``G+/SLT.H`$`````````
M`#P```3L__]RH````MP`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[H`@,""`K/
MSLW,R\K)R,?&#J`!0@L````````4```%+/__M^`````L```````````````T
M```%1/__M_@```!D`$:(#(D+B@J+"8P(C0>.!H\%1`[``@)8S\[-S,O*R<@.
MH`$``````````!0```5\__^X*`````(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````@``G^`````"``"?(
M`````````````````````0`````````!``````````$````````"!0``````
M```!`````````A```````````0````````(:``````````$````````":0``
M```````!`````````YH`````````#`````"``!P0``````````T`````@`!J
M4``````````9`````(``S<@`````````&P`````````(`````````!H`````
M@`#-T``````````<``````````@`````;__^]0````"```*0``````````4`
M````@``/0``````````&`````(``!;``````````"@````````4:````````
M``L`````````&``````````5`````````````````````P````"``-``````
M``````(````````%T``````````4``````````<`````````%P````"``!9`
M``````````<`````@``5F``````````(`````````*@`````````"0``````
M```8`````&____X`````@``5*`````!O____``````````(`````;___\```
M``"``!1:````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(``S>```````````````````````````(``''X`
M````@``<G@````"``!R^`````(``'-X`````@``<_@````"``!T>`````(``
M'3X`````@``=7@````"``!U^`````(``'9X`````@``=O@````"``!W>````
M`(``'?X`````@``>'@````"``!X^`````(``'EX`````@``>?@````"``!Z>
M`````(``'KX`````@``>W@````"``![^`````(``'QX`````@``?/@````"`
M`!]>`````(``'WX`````@``?G@````"``!^^`````(``']X`````@``?_@``
M``"``"`>`````(``(#X`````@``@7@````"``"!^`````(``()X`````@``@
MO@````"``"#>`````(``(/X`````@``A'@````"``"$^`````(``(5X`````
M@``A?@````"``"&>`````(``(;X`````@``AW@````"``"'^`````(``(AX`
M````@``B/@````"``")>`````(``(GX`````@``BG@````"``"*^`````(``
M(MX`````@``B_@````"``",>`````(``(SX`````@``C7@````"``"-^````
M`(``(YX`````@``CO@````"``"/>`````(``(_X`````@``D'@``````````
M````````````````````````````````_____P``````````@`!OMD=#0SH@
M*$1E8FEA;B`T+CDN,BTQ,"D@-"XY+C(`1T-#.B`H1&5B:6%N(#0N."XS+3$S
M*2`T+C@N,P``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0`````````"`````(```C@````````".```
M```````/`````````````````````0``````````````$P````<`````````
M`@````"```)(`````````D@`````````(`````````````````````0`````
M`````````"$````'``````````(`````@``":`````````)H`````````"0`
M```````````````````$```````````````T;___]@`````````"`````(``
M`I`````````"D`````````,<````!0``````````````"```````````````
M/@````L``````````@````"```6P````````!;`````````)D`````8````!
M``````````@`````````&````$8````#``````````(`````@``/0```````
M``]`````````!1H````````````````````!``````````````!.;____P``
M```````"`````(``%%H````````46@````````#,````!0``````````````
M`@`````````"````6V____X``````````@````"``!4H````````%2@`````
M````<`````8````"``````````@``````````````&H````$``````````(`
M````@``5F````````!68`````````*@````%```````````````(````````
M`!@```!T````!`````````!"`````(``%D`````````60`````````70````
M!0````P`````````"``````````8````?@````$`````````!@````"``!P0
M````````'!``````````0`````````````````````0``````````````'D`
M```!``````````8`````@``<4````````!Q0````````!^``````````````
M```````$`````````"````"$`````0`````````&`````(``)#`````````D
M,````````$8@````````````````````"```````````````B@````$`````
M````!@````"``&I0````````:E``````````+`````````````````````0`
M`````````````)`````!``````````(`````@`!J@````````&J`````````
M03H````````````````````(``````````````"8`````0`````````"````
M`(``J[P```````"KO`````````#D````````````````````!```````````
M````I@````$``````````@````"``*R@````````K*`````````%E```````
M``````````````@``````````````+`````.``````````,`````@`#-R```
M`````+W(``````````@````````````````````(``````````````"\````
M#P`````````#`````(``S=````````"]T``````````(````````````````
M````"```````````````R`````$``````````P````"``,W8````````O=@`
M````````"`````````````````````@``````````````,T````&````````
M``,`````@`#-X````````+W@`````````B`````&```````````````(````
M`````!````#6`````0`````````#`````(``T`````````#```````````(8
M````````````````````"``````````(````VP````$``````````P````"`
M`-(8````````PA@`````````(`````````````````````@`````````````
M`.$````(``````````,`````@`#2.````````,(X````````$&``````````
M```````````(``````````````#F`````0`````````P````````````````
M``#".``````````Z`````````````````````0`````````!`````0````,`
M````````````````````````````PG(`````````[P``````````````````
*``$`````````````
